/*
 * Kurt Kinetic (New) Road Machine Power Meter
 *
 * ports.h - hardware definition
 *
 * (c) Axel (XL) Schwenke, axel.schwenke@gmx.net
 *
 * $Id: ports.h 228 2014-01-01 23:24:04Z schwenke $
 */

#ifndef PORTS_H
#define PORTS_H

/*
            ATMEGA328P Pinout
            -----------------
      ISP |Res       ADC5/PC5| RS
      DB0 |PD0            PC4| R/W
      DB1 |PD1            PC3| E
      DB2 |PD2            PC2|
      DB3 |PD3            PC1|
      DB4 |PD4/T0         PC0|
      +5V |Vcc            GND| GND
      GND |GND           ARef| +5V
     XTAL |XTAL1         AVcc| +5V
     XTAL |XTAL2          SCK| ISP
      DB5 |PD5           MISO| ISP
      DB6 |PD6           MOSI| ISP
      DB7 |PD7            PB2|
    Pulse |PB0/ICP1       PB1|
           ------------------

DB0 - DB7 .... Data Bus for LCD
RS, R/W, E ... LCD control lines
Pulse ........ Resistance unit RPM pulse
XTAL ......... 8MHz crystal
ISP .......... to ISP connector

*/

/* LCD characteristics */
#define LCD_LINES     4
#define LCD_DISP_LEN  20

/* LCD control Port & Pins */
#define LCD_CTRL_PORT    PORTC  /* port for control lines   */
#define LCD_RS_PIN       5      /* pin  for RS line         */
#define LCD_RW_PIN       4      /* pin  for RW line         */
#define LCD_E_PIN        3      /* pin  for Enable line     */

#define lcd_e_high()     LCD_CTRL_PORT |=  _BV(LCD_E_PIN)
#define lcd_e_low()      LCD_CTRL_PORT &= ~_BV(LCD_E_PIN)
#define lcd_rw_high()    LCD_CTRL_PORT |=  _BV(LCD_RW_PIN)
#define lcd_rw_low()     LCD_CTRL_PORT &= ~_BV(LCD_RW_PIN)
#define lcd_rs_high()    LCD_CTRL_PORT |=  _BV(LCD_RS_PIN)
#define lcd_rs_low()     LCD_CTRL_PORT &= ~_BV(LCD_RS_PIN)

/* LCD data port */
#define data_output()    DDRD = 0xFF
#define data_input()     DDRD = 0x00
#define data_write(x)    PORTD = (x)
#define data_read()      (PIND)

#endif
